@@ -2,5 +2,5 @@ from paypalrestsdk.api import Api, set_config, configure
 from paypalrestsdk.payments import Payment, Sale, Refund, Authorization, Capture
 from paypalrestsdk.vault import CreditCard
 from paypalrestsdk.openid_connect import Tokeninfo, Userinfo
-from paypalrestsdk.exceptions import *
+from paypalrestsdk.exceptions import ResourceNotFound, UnauthorizedAccess, MissingConfig
 from paypalrestsdk.version import __version__
